/*
 * Copyright [2022] [https://www.xiaonuo.vip]
 *
 * Snowy采用APACHE LICENSE 2.0开源协议，您在使用过程中，需要注意以下几点：
 *
 * 1.请不要删除和修改根目录下的LICENSE文件。
 * 2.请不要删除和修改Snowy源码头部的版权声明。
 * 3.本项目代码可免费商业使用，商业使用请保留源码和相关描述文件的项目出处，作者声明等。
 * 4.分发源码时候，请注明软件出处 https://www.xiaonuo.vip
 * 5.不可二次分发开源参与同类竞品，如有想法可联系团队xiaonuobase@qq.com商议合作。
 * 6.若您的项目无法满足以上几点，需要更多功能代码，获取Snowy商业授权许可，请在官网购买授权，地址为 https://www.xiaonuo.vip
 */
package vip.xiaonuo.biz.modular.bizloadtime.service.impl;

import cn.hutool.core.bean.BeanUtil;
import cn.hutool.core.collection.CollStreamUtil;
import cn.hutool.core.util.ObjectUtil;
import cn.hutool.core.util.StrUtil;
import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.baomidou.mybatisplus.extension.service.impl.ServiceImpl;
import org.springframework.stereotype.Service;
import org.springframework.transaction.annotation.Transactional;
import vip.xiaonuo.common.enums.CommonSortOrderEnum;
import vip.xiaonuo.common.exception.CommonException;
import vip.xiaonuo.common.page.CommonPageRequest;
import vip.xiaonuo.biz.modular.bizloadtime.entity.BizLoadTime;
import vip.xiaonuo.biz.modular.bizloadtime.mapper.BizLoadTimeMapper;
import vip.xiaonuo.biz.modular.bizloadtime.param.BizLoadTimeAddParam;
import vip.xiaonuo.biz.modular.bizloadtime.param.BizLoadTimeEditParam;
import vip.xiaonuo.biz.modular.bizloadtime.param.BizLoadTimeIdParam;
import vip.xiaonuo.biz.modular.bizloadtime.param.BizLoadTimePageParam;
import vip.xiaonuo.biz.modular.bizloadtime.service.BizLoadTimeService;

import java.util.List;

/**
 * 装货时间配置Service接口实现类
 *
 * @author fanzherong
 * @date  2025/05/29 14:55
 **/
@Service
public class BizLoadTimeServiceImpl extends ServiceImpl<BizLoadTimeMapper, BizLoadTime> implements BizLoadTimeService {

    @Override
    public Page<BizLoadTime> page(BizLoadTimePageParam bizLoadTimePageParam) {
        QueryWrapper<BizLoadTime> queryWrapper = new QueryWrapper<BizLoadTime>().checkSqlInjection();
        if(ObjectUtil.isAllNotEmpty(bizLoadTimePageParam.getSortField(), bizLoadTimePageParam.getSortOrder())) {
            CommonSortOrderEnum.validate(bizLoadTimePageParam.getSortOrder());
            queryWrapper.orderBy(true, bizLoadTimePageParam.getSortOrder().equals(CommonSortOrderEnum.ASC.getValue()),
                    StrUtil.toUnderlineCase(bizLoadTimePageParam.getSortField()));
        } else {
            queryWrapper.lambda().orderByAsc(BizLoadTime::getId);
        }
        return this.page(CommonPageRequest.defaultPage(), queryWrapper);
    }

    @Transactional(rollbackFor = Exception.class)
    @Override
    public void add(BizLoadTimeAddParam bizLoadTimeAddParam) {
        BizLoadTime bizLoadTime = BeanUtil.toBean(bizLoadTimeAddParam, BizLoadTime.class);
        this.save(bizLoadTime);
    }

    @Transactional(rollbackFor = Exception.class)
    @Override
    public void edit(BizLoadTimeEditParam bizLoadTimeEditParam) {
        BizLoadTime bizLoadTime = this.queryEntity(bizLoadTimeEditParam.getId());
        BeanUtil.copyProperties(bizLoadTimeEditParam, bizLoadTime);
        this.updateById(bizLoadTime);
    }

    @Transactional(rollbackFor = Exception.class)
    @Override
    public void delete(List<BizLoadTimeIdParam> bizLoadTimeIdParamList) {
        // 执行删除
        this.removeByIds(CollStreamUtil.toList(bizLoadTimeIdParamList, BizLoadTimeIdParam::getId));
    }

    @Override
    public BizLoadTime detail(BizLoadTimeIdParam bizLoadTimeIdParam) {
        return this.queryEntity(bizLoadTimeIdParam.getId());
    }

    @Override
    public BizLoadTime queryEntity(String id) {
        BizLoadTime bizLoadTime = this.getById(id);
        if(ObjectUtil.isEmpty(bizLoadTime)) {
            throw new CommonException("装货时间配置不存在，id值为：{}", id);
        }
        return bizLoadTime;
    }
}
